#ifndef GRAPHICS_TEXT_H
#define GRAPHICS_TEXT_H

/*
**  text.h
**
**  (C) Copyright 1999-2004 Rocklyte Systems.
**      All Rights Reserved.
*/

#ifndef MAIN_H
#include <pandora/main.h>
#endif

/*****************************************************************************
** Text Flags.
*/

#define TXF_EDIT           0x00000001   /* Switch on to allow keyboard input */
#define TXF_ENTERACTIVATE  0x00000002   /* Activates children when the enter key is detected */
#define TXF_AUTOCLEAR      0x00000004   /* Clears the text when the enter key is pressed */
#define TXF_OVERWRITE      0x00000008   /* Turns on overwrite mode (if off, insert mode is enabled) */
#define TXF_TABENTRY       0x00000010   /* Tabs are the same as pressing enter */
#define TXF_FOCUSACTIVATE  0x00000020   /* Losing the focus after text entry activates the children */
#define TXF_WORDWRAP       0x00000040   /* Turn on to activate word wrapping */
#define TXF_HISTORY        0x00000080   /* Enable history browsing when cursor keys are used */
#define TXF_VARIABLE       0x00000100   /* Turns on active translation of references in a text string */
#define TXF_EFFECTLOOP     0x00000200   /* Allow special effects to repeat for animation sequences */
#define TXF_NOFXDRAW       0x00000400   /* Do not automatically draw effect changes */
#define TXF_FORCECAPS      0x00000800   /* Force capitalisation of text */
#define TXF_GLOBALEDITING  0x00001000   /* Keeps the text object in edit mode regardless of user focus */
#define TXF_AREASELECTED   0x00002000   /* Set if the user has selected some text */
#define TXF_NOSYSKEYS      0x00004000   /* System-keys provide standard key support for Ctrl-C, Ctrl-X etc.  Set this to turn them off */
#define TXF_MULTISELECT    0x00008000   /* Allow the user to select/highlight multiple lines by holding the Ctrl key */
#define TXF_SINGLESELECT   0x00010000   /* Enables text selection (with or without edit mode). */
#define TXF_DISABLED       0x00020000   /* Set if the object has had its user interactivity disabled */
#define TXF_BACKGROUND     0x00040000   /* Enables a colour background behind the text */
#define TXF_ENTERTAB       0x00080000   /* Convert enter-key presses to the tab-key */
#define TXF_PRESERVEBKGD   0x00100000   /* Preserve-background disables fast scrolling for background preservation */
#define TXF_SECRET         0x00200000   /* Secret text entry (for passwords) */
#define TXF_TABKEY         0x00400000   /* If the tab key is pressed, print the tab character */
#define TXF_AUTOSELECT     0x00800000   /* Automatically select all text if the text object receives the focus */

#define TXF_COMMANDLINE (TXF_ENTERACTIVATE|TXF_AUTOCLEAR|TXF_EDIT|TXF_HISTORY)
#define TXF_SELECT      (TXF_MULTISELECT|TXF_SINGLESELECT)
#define TXF_PASSWORD    TXF_SECRET

/*****************************************************************************
** Activation Flags.
*/

#define ACF_RELEASE      0x00000001   /* Releasing a mouse button will create an Activate action */
#define ACF_SINGLECLICK  0x00000002   /* Single clicking on any line will create an Activate action */
#define ACF_DOUBLECLICK  0x00000004   /* Double clicking on any line will create an Activate action */
#define ACF_MOVEMENT     0x00000008   /* Moving to a new line cause activation */

#define ACF_SENSITIVE    (ACF_SINGLECLICK|ACF_MOVEMENT)

/*****************************************************************************
** Text Effects
*/

#define EFX_TYPIST    1  /* Print the text gradually, as if someone is typing it in real time */
#define EFX_FLASH     2  /* Flash text to white before lowering the colour to its normal value */
#define EFX_FLASHDOWN 3  /* Private type */
#define EFX_FADE      4  /* Fade the text in to its normal colour value using alpha blending techniques */

/*****************************************************************************
** Text Methods.
*/

#define MT_AddTextLine     -1
#define MT_DeleteTextLine  -2
#define MT_GetTextLine     -3
#define MT_ReplaceTextLine -4
#define MT_SelectTextArea  -5
#define MT_FindText        -6
#define MT_ReplaceText     -7
#define MT_SetTextFont     -8
#define MT_ViewTextCursor  -9

struct mtAddTextLine {
   STRING String;
   LONG Line;
   LONG Length;
};

struct mtDeleteTextLine {
   LONG Line;
};

struct mtFindText {
   STRING String;
   LONG Flags;
   LONG Row;
   LONG Column;
};

struct mtGetTextLine {
   LONG Line;
   STRING Buffer;
   LONG Length;
};

struct mtReplaceTextLine {
   STRING String;
   LONG Line;
   LONG Length;
};

struct mtReplaceText {
   STRING Find;
   STRING Replace;
   LONG Flags;
};

struct mtSelectTextArea {
   LONG Row;
   LONG Column;
   LONG EndRow;
   LONG EndColumn;
};

struct mtSetTextFont {
   STRING Face;
};

/*** Flags for FindText() and ReplaceText() ***/

#define FTF_CASE       0x00000001
#define FTF_MOVECURSOR 0x00000002
#define FTF_HIGHLIGHT  0x00000004
#define FTF_FROMCURSOR 0x00000008
#define FTF_SELECTION  0x00000010
#define FTF_BACKWARDS  0x00000020
#define FTF_RESTART    0x00000040

#endif /* GRAPHICS_TEXT_H */
